==> james-project-3.7.6-source-release.zip: james-project/protocols/imap/src/main/java/org/apache/james/imap/encode/SearchResponseEncoder.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/
package org.apache.james.imap.encode;

import java.io.IOException;

import org.apache.james.imap.api.ImapConstants;
import org.apache.james.imap.message.response.SearchResponse;
import org.apache.james.mailbox.ModSeq;

/**
 * Encoders IMAP4rev1 <code>SEARCH</code> responses.
 */
public class SearchResponseEncoder implements ImapResponseEncoder<SearchResponse> {
    @Override
    public Class<SearchResponse> acceptableMessages() {
        return SearchResponse.class;
    }

    @Override
    public void encode(SearchResponse response, ImapResponseComposer composer) throws IOException {
        final long[] ids = response.getIds();
        ModSeq highestModSeq = response.getHighestModSeq();
        composer.untagged();
        composer.commandName(ImapConstants.SEARCH_COMMAND);
        if (ids != null) {
            for (long id : ids) {
                composer.message(id);
            }
        }
        
        // add MODSEQ
        if (highestModSeq != null) {
            composer.openParen();
            composer.message("MODSEQ");
            composer.message(highestModSeq.asLong());
            composer.closeParen();
        }
        composer.end();
    }
}

==> james-project-3.9.0-source-release.zip: james-project/protocols/imap/src/main/java/org/apache/james/imap/encode/SearchResponseEncoder.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/
package org.apache.james.imap.encode;

import java.io.IOException;

import org.apache.james.imap.api.ImapConstants;
import org.apache.james.imap.message.response.SearchResponse;
import org.apache.james.mailbox.ModSeq;

import it.unimi.dsi.fastutil.longs.LongConsumer;
import it.unimi.dsi.fastutil.longs.LongList;

/**
 * Encoders IMAP4rev1 <code>SEARCH</code> responses.
 */
public class SearchResponseEncoder implements ImapResponseEncoder<SearchResponse> {
    @Override
    public Class<SearchResponse> acceptableMessages() {
        return SearchResponse.class;
    }

    @Override
    public void encode(SearchResponse response, ImapResponseComposer composer) throws IOException {
        LongList ids = response.getIds();
        ModSeq highestModSeq = response.getHighestModSeq();
        composer.untagged();
        composer.commandName(ImapConstants.SEARCH_COMMAND);
        if (ids != null) {
            LongConsumer longConsumer = l -> {
                try {
                    composer.message(l);
                } catch (IOException e) {
                    throw new RuntimeException(e);
                }
            };
            ids.forEach(longConsumer);
        }
        
        // add MODSEQ
        if (highestModSeq != null) {
            composer.openParen();
            composer.message("MODSEQ");
            composer.message(highestModSeq.asLong());
            composer.closeParen();
        }
        composer.end();
    }
}
